@@ -1,8 +1,12 @@
-"""A module containing helper functions useful while constructing Factor Graphs."""
+"""A module containing helper functions."""
 
 import functools
 from typing import Callable
 
+NEG_INF = (
+    -100000.0
+)  # A large negative value to use as -inf for numerical stability reasons
+
 
 def cached_property(func: Callable) -> property:
     """Customized cached property decorator
